@@ -16,23 +16,9 @@
 #include <dirent.h>
 
 
+
 extern int liqcell_showdebugboxes;
 
-static int liqcell_ensurevisible(liqcell *self)
-{
-	
-/*	
-	liqcell *c = liqcell_getlinkchild(self);
-	while(c)
-	{
-		if(liqcell_getflagvisual(c))
-		{
-			if(!liqcell_getselected(c)) liqcell_setselected(c,1);
-		}
-		c=liqcell_getlinknext(c);
-	}
- */	return 0;
-}
 
 
 
@@ -121,6 +107,7 @@ static int liqcell_child_propremoves(liqcell *self,char *propname)
 
 
 
+
 
 
 static int liqcell_scan_folder_for_folders(liqcell *self,char *path,char *classtocreate,void *clickhandler,liqcell*clickcontext)
@@ -146,7 +133,7 @@ static int liqcell_scan_folder_for_folders(liqcell *self,char *path,char *classt
 			
 			ft=dir_entry_p->d_name;
 			
-			snprintf(fn , FILENAME_MAX , "%s/%s", widgetpath , ft);
+			snprintf(fn , FILENAME_MAX , "%s//%s", widgetpath , ft);
 			
 			struct stat     statbuf;
 			if(stat(fn, &statbuf) == -1)
@@ -320,18 +307,34 @@ static int liqcell_scan_folder_for_images(liqcell *self,char *path,char *classto
 		liqcell *fileitem1 = liqcell_child_lookup_simple(filebackplane,filename);
 		kotcomix_list_backplane_item_select(filebackplane, fileitem1 );
 		if(fileitem1) liqcell_ensurevisible(fileitem1);
+		
+		liqcell_propsets(self, "selectedfilename",   filename );
 					
 	}
 		
-
+	static int kotcomix_changedir(liqcell *self, char *newpath);
 
 
 	static int kotcomix_folderitem_click(liqcell *self, liqcellclickeventargs *args, liqcell *kotcomix)
 	{
-		//liqapp_log("clickity : %s:%s",self->name,self->classname);
+		liqapp_log("clickity : %s:%s",self->name,self->classname);
 		
-		kotcomix_selectfile(kotcomix,self->name);
 	
+		if(liqapp_folderexists(self->name))
+		{
+			// folder
+			liqcell_hold(self);
+			
+			kotcomix_changedir(kotcomix, self->name);
+			
+			liqcell_release(self);
+		}
+		else
+		{
+			// file
+			kotcomix_selectfile(kotcomix,self->name);
+		}
+		
 	
 	/*
 		
@@ -418,6 +421,10 @@ static int kotcomix_changedir(liqcell *self, char *newpath)
 	liqcell_child_removeallvisual( folderbackplane );
 	liqcell_child_removeallvisual( filebackplane );
 	
+	liqcell_setcaption(title, newpath );
+	
+	liqcell_propsets(self, "startpath", newpath );
+	
 	
 	liqcell_setrect(folderbackplane, 0,0,folderlist->w,folderlist->h);
 
@@ -439,15 +446,63 @@ static int kotcomix_changedir(liqcell *self, char *newpath)
 	liqcell_child_arrange_autoflow(filebackplane);
 }
 
+/**	
+ * kotcomix.title clicked
+ */	
+static int title_click(liqcell *title,liqcelleventargs *args, liqcell *self)
+{
+	liqcell *buttonaccept = liqcell_child_lookup(self, "buttonaccept");
+	liqcell *folderlist = liqcell_child_lookup(self, "folderlist");
+		liqcell *folderbackplane = liqcell_child_lookup(folderlist, "folderbackplane");
+			//liqcell *folderitem1 = liqcell_child_lookup(folderbackplane, "folderitem1");
+	liqcell *filelist = liqcell_child_lookup(self, "filelist");
+		liqcell *filebackplane = liqcell_child_lookup(filelist, "filebackplane");
+			//liqcell *fileitem1 = liqcell_child_lookup(filebackplane, "fileitem1");
+	//liqcell *title = liqcell_child_lookup(self, "title");
+	liqcell *icon = liqcell_child_lookup(self, "icon");
+	liqcell *label5 = liqcell_child_lookup(self, "label5");
+	liqcell *label6 = liqcell_child_lookup(self, "label6");
+	liqcell *label7 = liqcell_child_lookup(self, "label7");
+	liqcell *label1 = liqcell_child_lookup(self, "label1");	
+	
+	
+	char * startpath = liqcell_propgets(self, "startpath", "/usr/share/liqbase/media");
+	if(!startpath)return 0;
+	// take a copy
+	char buf[FILENAME_MAX];
+	snprintf(buf,sizeof(buf),startpath);
+	char *allpath=buf;	
+	char *lastpart = liqapp_filename_walkoverpath(allpath);
+	
+	if(lastpart && lastpart>allpath)
+	{
+		lastpart[-1]=0;
+		
+		if(*allpath)
+		{
+		
+			kotcomix_changedir(self, allpath);
+		}
+		else
+		{
+			kotcomix_changedir(self, "/");
+		}
+		
+	}
 
+}
 
 /**	
  * kotcomix widget shown
  */	
 static int kotcomix_shown(liqcell *self,liqcelleventargs *args, void *context)
 {
-	// test..
-	kotcomix_changedir(self, "/home/user/svn/liqbase-playground/src/media");
+	// 20090618_020248 lcuk : expect to be passed a parameter to specify "startpath"
+	char * startpath = liqcell_propgets(self, "startpath", "/usr/share/liqbase/media");
+	
+	liqapp_log("kotcomix.startpath=%s",startpath);
+	
+	kotcomix_changedir(self, startpath);
 }
 /**	
  * kotcomix widget refresh, all params set, present yourself to the user.
@@ -461,9 +516,23 @@ static int kotcomix_refresh(liqcell *self,liqcelleventargs *args, void *context)
 /**	
  * kotcomix.buttonaccept clicked
  */	
-//static int buttonaccept_click(liqcell *self,liqcelleventargs *args, liqcell *kotcomix)
-//{
-//}
+static int buttonaccept_click(liqcell *self,liqcelleventargs *args, liqcell *kotcomix)
+{
+}
+
+
+/**	
+ * kotcomix.quicklocation clicked
+ */	
+static int quicklocation_click(liqcell *self,liqcelleventargs *args, liqcell *kotcomix)
+{
+	// read the location from a property :)
+	
+	char * startpath = liqcell_propgets(self, "startpath", "/usr/share/liqbase/media");
+	
+	kotcomix_changedir(kotcomix, startpath);
+}
+
 /**	
  * kotcomix_child_test_seek this function shows how to access members
  */	
@@ -495,12 +564,6 @@ liqcell *kotcomix_create()
 	liqcell *self = liqcell_quickcreatewidget("kotcomix", "form", 800, 480);
 	if(!self) {liqapp_log("liqcell error not create 'kotcomix'"); return NULL;  } 
 	
-	//############################# buttonaccept:commandbutton
-	//liqcell *buttonaccept = liqcell_quickcreatevis("buttonaccept", "commandbutton", 716, 426, 74, 42);
-	//liqcell_setcaption(buttonaccept, "OK" );
-	//liqcell_propsets(  buttonaccept, "backcolor", "rgb(0,255,0)" );
-	//liqcell_handleradd_withcontext(buttonaccept, "click", buttonaccept_click, self );
-	//liqcell_child_append(  self, buttonaccept);
 	//############################# folderlist:frame
 	liqcell *folderlist = liqcell_quickcreatevis("folderlist", "frame", 54, 46, 344, 422);
 	//liqcell_setfont(	folderlist, liqfont_cache_getttf("/usr/share/fonts/nokia/nosnb.ttf", (12), 0) );
@@ -520,7 +583,7 @@ liqcell *kotcomix_create()
 		liqcell_child_append(  folderlist, folderbackplane);
 	liqcell_child_append(  self, folderlist);
 	//############################# filelist:frame
-	liqcell *filelist = liqcell_quickcreatevis("filelist", "frame", 402, 46, 392, 422);
+	liqcell *filelist = liqcell_quickcreatevis("filelist", "frame", 402, 46, 392, 480-46-40);
 	//liqcell_setfont(	filelist, liqfont_cache_getttf("/usr/share/fonts/nokia/nosnb.ttf", (12), 0) );
 	//liqcell_setcaption(filelist, "Frame1" );
 	//liqcell_propsets(  filelist, "textcolor", "rgb(255,255,255)" );
@@ -543,18 +606,20 @@ liqcell *kotcomix_create()
 	liqcell *title = liqcell_quickcreatevis("title", "label", 62, 0, 546, 42);
 	liqcell_setfont(	title, liqfont_cache_getttf("/usr/share/fonts/nokia/nosnb.ttf", (29), 0) );
 	liqcell_setcaption(title, "kot comix" );
-	liqcell_propsets(  title, "textcolor", "rgb(255,255,255)" );
+	liqcell_propsets(  title, "textcolor", "rgb(255,100,100)" );
 	liqcell_propsets(  title, "backcolor", "rgb(0,0,0)" );
 	liqcell_propseti(  title, "textalign", 0 );
+	liqcell_handleradd_withcontext(title, "click", title_click, self );
 	liqcell_child_append(  self, title);
 	//############################# icon:label
 	liqcell *icon = liqcell_quickcreatevis("icon", "label", 2, 2, 52, 40);
 	liqcell_setfont(	icon, liqfont_cache_getttf("/usr/share/fonts/nokia/nosnb.ttf", (12), 0) );
-	liqcell_setcaption(icon, "icon" );
+	liqcell_setcaption(icon, ".." );
 	liqcell_propsets(  icon, "textcolor", "rgb(255,255,255)" );
 	liqcell_propsets(  icon, "backcolor", "rgb(0,0,128)" );
 	liqcell_propsets(  icon, "bordercolor", "rgb(200,100,100)" );
 	liqcell_propseti(  icon, "textalign", 2 );
+	liqcell_handleradd_withcontext(icon, "click", title_click, self );
 	liqcell_child_append(  self, icon);
 	//############################# label5:label
 	liqcell *label5 = liqcell_quickcreatevis("label5", "label", 2, 90, 52, 76);
@@ -564,6 +629,10 @@ liqcell *kotcomix_create()
 	liqcell_propsets(  label5, "backcolor", "rgb(0,128,128)" );
 	liqcell_propsets(  label5, "bordercolor", "rgb(200,100,100)" );
 	liqcell_propseti(  label5, "textalign", 2 );
+
+	liqcell_propsets(  label5, "startpath", "/home/user/MyDocs" );
+	liqcell_handleradd_withcontext(label5, "click", quicklocation_click, self );
+
 	liqcell_child_append(  self, label5);
 	//############################# label6:label
 	liqcell *label6 = liqcell_quickcreatevis("label6", "label", 2, 172, 52, 68);
@@ -573,6 +642,10 @@ liqcell *kotcomix_create()
 	liqcell_propsets(  label6, "backcolor", "rgb(0,128,128)" );
 	liqcell_propsets(  label6, "bordercolor", "rgb(200,100,100)" );
 	liqcell_propseti(  label6, "textalign", 2 );
+	
+	liqcell_propsets(  label6, "startpath", "/media/mmc1" );
+	liqcell_handleradd_withcontext(label6, "click", quicklocation_click, self );
+
 	liqcell_child_append(  self, label6);
 	//############################# label7:label
 	liqcell *label7 = liqcell_quickcreatevis("label7", "label", 0, 246, 54, 64);
@@ -583,16 +656,53 @@ liqcell *kotcomix_create()
 	liqcell_propsets(  label7, "bordercolor", "rgb(200,100,100)" );
 	liqcell_propseti(  label7, "textalign", 2 );
 	liqcell_child_append(  self, label7);
+
+	liqcell_propsets(  label7, "startpath", "/media/mmc2" );
+	liqcell_handleradd_withcontext(label7, "click", quicklocation_click, self );
+
 	//############################# label1:label
 	liqcell *label1 = liqcell_quickcreatevis("label1", "label", 0, 318, 54, 64);
 	liqcell_setfont(	label1, liqfont_cache_getttf("/usr/share/fonts/nokia/nosnb.ttf", (12), 0) );
-	liqcell_setcaption(label1, "root" );
+	liqcell_setcaption(label1, "liq" );
 	liqcell_propsets(  label1, "textcolor", "rgb(255,255,255)" );
 	liqcell_propsets(  label1, "backcolor", "rgb(0,128,128)" );
 	liqcell_propsets(  label1, "bordercolor", "rgb(200,100,100)" );
 	liqcell_propseti(  label1, "textalign", 2 );
+
+	liqcell_propsets(  label1, "startpath", "/usr/share/liqbase/media" );
+	liqcell_handleradd_withcontext(label1, "click", quicklocation_click, self );
+
 	liqcell_child_append(  self, label1);
 	//liqcell_propsets(  self, "backcolor", "rgb(0,0,0)" );
+
+
+	//############################# buttonview:commandbutton
+	liqcell *buttonview = liqcell_quickcreatevis("buttonview", "commandbutton", 400, 440, 200, 40);
+	liqcell_setfont(	buttonview, liqfont_cache_getttf("/usr/share/fonts/nokia/nosnb.ttf", (35), 0) );
+	liqcell_setcaption(buttonview, "view" );
+	liqcell_propsets(  buttonview, "textcolor",   "rgb(100,100,255)" );
+	liqcell_propsets(  buttonview, "backcolor",   "rgb(0,0,40)" );
+	liqcell_propsets(  buttonview, "bordercolor", "rgb(0,0,150)" );
+	liqcell_propseti(  buttonview, "textalign",   2 );
+	liqcell_propseti(  buttonview, "textaligny",  2 );
+	liqcell_child_append(  self, buttonview);
+
+
+
+	//############################# buttonaccept:commandbutton
+	liqcell *buttonaccept = liqcell_quickcreatevis("buttonaccept", "commandbutton", 600, 440, 200, 40);
+	liqcell_setfont(	buttonaccept, liqfont_cache_getttf("/usr/share/fonts/nokia/nosnb.ttf", (35), 0) );
+	liqcell_setcaption(buttonaccept, "select" );
+	liqcell_propsets(  buttonaccept, "textcolor",   "rgb(0,255,0)" );
+	liqcell_propsets(  buttonaccept, "backcolor",   "rgb(0,40,0)" );
+	liqcell_propsets(  buttonaccept, "bordercolor", "rgb(0,150,0)" );
+	liqcell_propseti(  buttonaccept, "textalign",   2 );
+	liqcell_propseti(  buttonaccept, "textaligny",  2 );
+	liqcell_child_append(  self, buttonaccept);
+
+
+
+
 	liqcell_handleradd(self, "refresh", kotcomix_refresh );
 	liqcell_handleradd(self, "shown", kotcomix_shown );
 	
