@@ -209,7 +209,7 @@ int main (int argc, char* argv[])
 
 	//########################################################## prepare the app
 
-	if(liqapp_init(   argc,argv ,"liqbase-playground" ,"0.2") != 0)
+	if(liqapp_init(   argc,argv ,"liqbase-playground" ,"0.3") != 0)
 	{
 		{ return liqapp_errorandfail(-1,"liqapp_init failed"); }
 	}
@@ -253,7 +253,7 @@ int main (int argc, char* argv[])
 	// goodbye, see you again
 	
 	
-	system("browser --url=http://liqbase.net/playground.html");
+	//system("browser --url=http://liqbase.net/playground.html");
 	
     
 
@@ -366,7 +366,7 @@ liqcell *widgetrecent=NULL;
 		int isok=0;
 		char *showwidget_arg = liqapp_getopt_str("showwidget",NULL);
         
-        if(!showwidget_arg) showwidget_arg="kotcomix,tagcloud,liqcontrolpanel,liqrecentpics,liqcalendar,liqrecentphotos,ciroclock_minutes,liqtop,liqrecentsketches,liqrecentusers,liqaccelview,liqbook";
+        if(!showwidget_arg) showwidget_arg="tagcloud,liqcontrolpanel,liqrecentpics,liqcalendar,liqrecentphotos,ciroclock_minutes,liqtop,liqrecentsketches,liqrecentusers,liqaccelview,liqbook";
         
 		
 		if(showwidget_arg && *showwidget_arg)
